Struct UpDownCounter

#[non_exhaustive]
pub struct UpDownCounter<T>(/* private fields */);
An instrument that records increasing or decreasing values.

UpDownCounter can be cloned to create multiple handles to the same instrument. If a UpDownCounter needs to be shared, users are recommended to clone the UpDownCounter instead of creating duplicate UpDownCounters for the same metric. Creating duplicate UpDownCounters for the same metric could lower SDK performance.

Implementations

Source

impl<T> UpDownCounter<T>

pub fn new(inner: Arc<dyn SyncInstrument<T> + Sync + Send>) -> UpDownCounter<T>

Create a new up down counter.

pub fn add(&self, value: T, attributes: &[KeyValue])

Records an increment or decrement to the counter.